==> aws-java-sdk-codecommit-1.10.63-sources.jar: com/amazonaws/services/codecommit/model/transform/UpdateRepositoryNameRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.codecommit.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.codecommit.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * UpdateRepositoryNameRequest Marshaller
 */
public class UpdateRepositoryNameRequestMarshaller
        implements
        Marshaller<Request<UpdateRepositoryNameRequest>, UpdateRepositoryNameRequest> {

    public Request<UpdateRepositoryNameRequest> marshall(
            UpdateRepositoryNameRequest updateRepositoryNameRequest) {

        if (updateRepositoryNameRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<UpdateRepositoryNameRequest> request = new DefaultRequest<UpdateRepositoryNameRequest>(
                updateRepositoryNameRequest, "AWSCodeCommit");
        request.addHeader("X-Amz-Target",
                "CodeCommit_20150413.UpdateRepositoryName");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final SdkJsonGenerator jsonGenerator = new SdkJsonGenerator();

            jsonGenerator.writeStartObject();

            if (updateRepositoryNameRequest.getOldName() != null) {
                jsonGenerator.writeFieldName("oldName").writeValue(
                        updateRepositoryNameRequest.getOldName());
            }
            if (updateRepositoryNameRequest.getNewName() != null) {
                jsonGenerator.writeFieldName("newName").writeValue(
                        updateRepositoryNameRequest.getNewName());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-codecommit-1.11.29-sources.jar: com/amazonaws/services/codecommit/model/transform/UpdateRepositoryNameRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.codecommit.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.codecommit.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * UpdateRepositoryNameRequest Marshaller
 */
public class UpdateRepositoryNameRequestMarshaller
        implements
        Marshaller<Request<UpdateRepositoryNameRequest>, UpdateRepositoryNameRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public UpdateRepositoryNameRequestMarshaller(
            SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<UpdateRepositoryNameRequest> marshall(
            UpdateRepositoryNameRequest updateRepositoryNameRequest) {

        if (updateRepositoryNameRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<UpdateRepositoryNameRequest> request = new DefaultRequest<UpdateRepositoryNameRequest>(
                updateRepositoryNameRequest, "AWSCodeCommit");
        request.addHeader("X-Amz-Target",
                "CodeCommit_20150413.UpdateRepositoryName");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory
                    .createGenerator();

            jsonGenerator.writeStartObject();

            if (updateRepositoryNameRequest.getOldName() != null) {
                jsonGenerator.writeFieldName("oldName").writeValue(
                        updateRepositoryNameRequest.getOldName());
            }
            if (updateRepositoryNameRequest.getNewName() != null) {
                jsonGenerator.writeFieldName("newName").writeValue(
                        updateRepositoryNameRequest.getNewName());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
